gchecky.controller.ControllerContext

Package gchecky :: Module controller :: Class ControllerContext |
[hide private]
[frames] | no frames]

# Class ControllerContext

source code

    object --+
             |
            ControllerContext

Instance Methods | [hide private]
__init__(self, outgoing=True) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
| outgoing = `True`
| xml = `None`
| message = `None`
| diagnose = `False`
| order_id = `None`
| serial = `None`
| response_message = `None`
| response_xml = `None`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, outgoing=True) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)